@@ -5,6 +5,7 @@
  *	Ettore Perazzoli <ettore@perazzoli.org>
  *	Larry Ewing <lewing@gnome.org>
  *	Stephane Delcroix <stephane@delcroix.org>
+ *	Thomas Van Machelen <thomas.vanmachelen@gmail.com>
  * 
  * This is free software. See COPYING for details.
  */
@@ -16,6 +17,7 @@ namespace FSpot
 		Photo photo;
 		uint version_id;
 		System.Uri uri;
+		string md5_sum;
 		string name;
 		bool is_protected;
 	
@@ -52,6 +54,11 @@ namespace FSpot
 				uri = value;
 			}
 		}
+
+		public string MD5Sum {
+			get { return md5_sum; } 
+			internal set { md5_sum = value; }
+		}
 	
 		public uint VersionId {
 			get { return version_id; }
@@ -65,11 +72,12 @@ namespace FSpot
 			get { return photo.Rating; }
 		}
 	
-		public PhotoVersion (Photo photo, uint version_id, System.Uri uri, string name, bool is_protected)
+		public PhotoVersion (Photo photo, uint version_id, System.Uri uri, string md5_sum, string name, bool is_protected)
 		{
 			this.photo = photo;
 			this.version_id = version_id;
 			this.uri = uri;
+			this.md5_sum = md5_sum;
 			this.name = name;
 			this.is_protected = is_protected;
 		}
