@@ -9,6 +9,7 @@
 
 using FSpot;
 using FSpot.Utils;
+using FSpot.Widgets;
 
 using Gdk;
 using Gtk;
@@ -29,14 +30,9 @@ namespace FSpot.Editors {
 		}
 	}
 
-	public class EditorSelection {
-		public int x, y;
-		public int width, height;
-	}
-
 	public class EditorState {
 		// The area selected by the user.
-		public EditorSelection Selection;
+		public Rectangle Selection;
 
 		// The images selected by the user.
 		public IBrowsableItem [] Items;
@@ -46,7 +42,7 @@ namespace FSpot.Editors {
 
 		// Has a portion of the image been selected?
 		public bool HasSelection {
-			get { return Selection != null; }
+			get { return Selection != Rectangle.Zero; }
 		}
 
 		// Is the user in browse mode?
@@ -88,7 +84,7 @@ namespace FSpot.Editors {
 		// A tool can be applied if it doesn't need a selection, or if it has one.
 		public bool CanBeApplied {
 			get {
-				Log.DebugFormat ("{0} can be applied? {1}", this, !NeedsSelection || (NeedsSelection && State.HasSelection));
+				Log.Debug ("{0} can be applied? {1}", this, !NeedsSelection || (NeedsSelection && State.HasSelection));
 				return !NeedsSelection || (NeedsSelection && State.HasSelection);
 			}
 		}
@@ -234,7 +230,7 @@ namespace FSpot.Editors {
 				width = (int) (iwidth / ratio);
 				height = (int) (iheight / ratio);
 			}
-			//Log.DebugFormat ("Preview size: Allocation: {0}x{1}, Input: {2}x{3}, Result: {4}x{5}", awidth, aheight, iwidth, iheight, width, height);
+			//Log.Debug ("Preview size: Allocation: {0}x{1}, Input: {2}x{3}, Result: {4}x{5}", awidth, aheight, iwidth, iheight, width, height);
 		}
 
 		public void Restore () {
@@ -269,8 +265,8 @@ namespace FSpot.Editors {
 			return new EditorState ();
 		}
 
-		public event InitializedHandler Initialized;
 		public delegate void InitializedHandler ();
+		public event InitializedHandler Initialized;
 
 		public void Initialize (EditorState state) {
 			State = state;
