@@ -3,7 +3,11 @@ using System.IO;
 using System.Collections;
 using LibGPhoto2;
 using Gdk;
-
+using FSpot.Utils;
+using FSpot;
+#if GPHOTO2_2_4
+using Mono.Unix.Native;
+#endif
 public class GPhotoCamera
 {
 	Context context;
@@ -69,11 +73,11 @@ public class GPhotoCamera
 
 		
 		string path  = camera_list.GetValue (selected_camera__camera_list_index);
-		System.Console.WriteLine ("Testing gphoto path = {0}", path);
+		Log.Debug ("Testing gphoto path = {0}", path);
 		selected_camera__port_info_list_index = port_info_list.LookupPath (path);
 
 		port_info = port_info_list.GetInfo (selected_camera__port_info_list_index);
-		System.Console.WriteLine ("PortInfo {0}, {1}", port_info.Name, port_info.Path);
+		Log.Debug ("PortInfo {0}, {1}", port_info.Name, port_info.Path);
 
 		camera.SetPortInfo (port_info);
 	}
@@ -167,7 +171,7 @@ public class GPhotoCamera
 									       CameraFileType.Preview,
 									       context);
 			} catch (System.Exception e) {
-				System.Console.WriteLine (e.ToString ());
+				Log.Exception (e);
 				selected_file.PreviewFile = null;
 			}
 		}
@@ -183,12 +187,16 @@ public class GPhotoCamera
 			if (bytedata.Length > 0) {
 				MemoryStream dataStream = new MemoryStream (bytedata);
 				try {
-					return new Pixbuf (dataStream);
+					Gdk.Pixbuf temp = new Pixbuf (dataStream);
+					Cms.Profile screen_profile;
+					if (FSpot.ColorManagement.Profiles.TryGetValue (Preferences.Get<string> (Preferences.COLOR_MANAGEMENT_DISPLAY_PROFILE), out screen_profile)) 
+						FSpot.ColorManagement.ApplyProfile (temp, screen_profile);
+					return temp;
 				} catch (Exception e) {
 					// Actual errors with the data libgphoto gives us have been
 					// observed here see b.g.o #357569. 
-					Console.WriteLine ("Error retrieving preview image");
-					Console.WriteLine (e);
+					Log.Information ("Error retrieving preview image");
+					Log.DebugException (e);
 				}
 					
 			}
@@ -204,7 +212,18 @@ public class GPhotoCamera
 		//check if the directory exists
 		if (!Directory.Exists (Path.GetDirectoryName (filename))) 
 			throw new Exception (String.Format ("Directory \"{0}\"does not exist", filename)); //FIXME
-		
+#if GPHOTO2_2_4
+		//gp_file_new_from_fd is broken on the directory driver
+		//but using gp_file_new_from_fd doesn't move the files to memory
+		if (camera_abilities.port != PortType.Disk) {
+			GPhotoCameraFile selected_file = (GPhotoCameraFile) files [index];		
+			using (var f = new CameraFile (Syscall.open (filename, OpenFlags.O_CREAT|OpenFlags.O_RDWR, FilePermissions.DEFFILEMODE))) {
+				camera.GetFile (selected_file.Directory, selected_file.FileName, CameraFileType.Normal, f, context);
+			}
+			return;
+		}
+#endif
+	
 		using (CameraFile camfile = GetFile (index)) {
 			if (camfile == null) 
 				throw new Exception ("Unable to claim file"); //FIXME
@@ -251,7 +270,7 @@ public class GPhotoCamera
 }
 
 	
-public class GPhotoCameraFile
+public class GPhotoCameraFile : IComparable
 {
 	string directory;
 	string filename;
@@ -297,7 +316,7 @@ public class GPhotoCameraFile
 		}
 	}
 	
-	public void ReleaseGPhotoResources()
+	public void ReleaseGPhotoResources ()
 	{
 		if (normal != null) 
 			normal.Dispose ();
@@ -305,4 +324,13 @@ public class GPhotoCameraFile
 		if (preview != null) 
 			preview.Dispose ();
 	}
+
+	public int CompareTo (object obj)
+	{
+		GPhotoCameraFile f2 = obj as GPhotoCameraFile;
+		int result = Directory.CompareTo (f2.Directory);
+		if (result == 0)
+			result = FileName.CompareTo (f2.FileName);
+		return result;
+	}
 }
