@@ -1,14 +1,34 @@
+/*
+ * FSpot.QueryWidget.cs
+ *
+ * Author(s):
+ *	Gabriel Burt
+ *
+ * This is free software. See COPYING for details.
+ */
+
+
+using System;
+using System.Collections.Generic;
+
+using Mono.Unix;
+
+using Gtk;
+
+using FSpot.Utils;
 using FSpot.Query;
 using FSpot.Widgets;
-using Mono.Unix;
-using Gtk;
+
+
 
 namespace FSpot {
 
 	public class QueryWidget : HighlightedBox {
 		PhotoQuery query;
 		LogicWidget logic_widget;
-	        Gtk.HBox box;
+		FolderQueryWidget folder_query_widget;
+		
+		Gtk.HBox box;
 		Gtk.Label label;
 		Gtk.Label untagged;
 		Gtk.Label rated;
@@ -21,12 +41,10 @@ namespace FSpot {
 		Gtk.Tooltips tips = new Gtk.Tooltips ();
 
 		public LogicWidget Logic {
-			get {
-				return logic_widget;
-			}
+			get { return logic_widget; }
 		}
 
-		public QueryWidget (PhotoQuery query, Db db, TagSelectionWidget selector) : base(new HBox())
+		public QueryWidget (PhotoQuery query, Db db) : base(new HBox())
 		{
 			box = Child as HBox;
 			box.Spacing = 6;
@@ -63,7 +81,11 @@ namespace FSpot {
 			rollfilter.Visible = false;
 			box.PackStart (rollfilter, false, false, 0);
 
-			logic_widget = new LogicWidget (query, db.Tags, selector);
+			folder_query_widget = new FolderQueryWidget ();
+			folder_query_widget.Visible = false;
+			box.PackStart (folder_query_widget, false, false, 0);
+			
+			logic_widget = new LogicWidget (query, db.Tags);
 			logic_widget.Show ();
 			box.PackStart (logic_widget, true, true, 0);
 
@@ -120,6 +142,11 @@ namespace FSpot {
 			query.RatingRange = null;
 			logic_widget.Clear = true;
 			logic_widget.UpdateQuery ();
+			
+			folder_query_widget.Clear ();
+			query.RequestReload ();
+			
+			HideBar ();
 		}
 
 		public void ShowBar ()
@@ -136,14 +163,17 @@ namespace FSpot {
 
 		public void HandleChanged (IBrowsableCollection collection) 
 		{
-			if (query.ExtraCondition == null)
+			if (query.TagTerm == null)
 				logic_widget.Clear = true;
 
-			if (!logic_widget.Clear || query.Untagged || (query.RollSet != null) || (query.RatingRange != null)) {
-		                ShowBar ();
-			} else {
+			if ( ! logic_widget.Clear
+			    || query.Untagged
+			    || (query.RollSet != null)
+			    || (query.RatingRange != null)
+			    || ! folder_query_widget.Empty)
+				ShowBar ();
+			else
 				HideBar ();
-			}
 
 			untagged.Visible = query.Untagged;
 			rated.Visible = (query.RatingRange != null);
@@ -189,5 +219,11 @@ namespace FSpot {
 		{
 			return logic_widget.TagRequired (tag);
 		}
+		
+		public void SetFolders (IEnumerable<Uri> uri_list)
+		{
+			folder_query_widget.SetFolders (uri_list);
+			query.RequestReload ();
+		}
 	}
 }
