@@ -84,7 +84,7 @@ namespace FSpot.Widgets {
 
 		private void HandleEntryTextInserted (object sender, TextInsertedArgs args)
 		{
-			//Log.DebugFormat ("inserting {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
+			//Log.Debug ("inserting {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
 
 			//int start = args.Position - args.Length;
 
@@ -114,7 +114,7 @@ namespace FSpot.Widgets {
 		private void HandleEntryTextDeleted (object sender, TextDeletedArgs args)
 		{
 			int length = args.EndPos - args.StartPos;
-			//Log.DebugFormat ("start {0} end {1} len {2} last {3}", args.StartPos, args.EndPos, length, last_entry_text);
+			//Log.Debug ("start {0} end {1} len {2} last {3}", args.StartPos, args.EndPos, length, last_entry_text);
 			string txt = last_entry_text.Substring (args.StartPos, length);
 
 			for (int i = 0; i < txt.Length; i++) {
@@ -202,9 +202,9 @@ namespace FSpot.Widgets {
 		private static void PrintGroup (GroupCollection groups, string name)
 		{
 			Group group = groups [name];
-			Log.DebugFormat ("Name: {2} (success = {1}) group: {0}", group, group.Success, name);
+			Log.Debug ("Name: {2} (success = {1}) group: {0}", group, group.Success, name);
 			foreach (Capture capture in group.Captures) {
-				Log.DebugFormat ("  Have capture: {0}", capture);
+				Log.Debug ("  Have capture: {0}", capture);
 			}
 		}
 
@@ -223,7 +223,7 @@ namespace FSpot.Widgets {
 
 			string indent = String.Format ("{0," + depth*2 + "}", " ");
 
-			//Log.DebugFormat (indent + "Have text: {0}", txt);
+			//Log.Debug (indent + "Have text: {0}", txt);
 
 			// Match the query the user typed against our regular expression
 			Match match = term_regex.Match (txt);
@@ -254,7 +254,7 @@ namespace FSpot.Widgets {
 			}
 
 			if (match.Groups ["Terms"].Captures.Count == 1 && match.Groups["NotTerm"].Captures.Count != 1) {
-				//Log.DebugFormat (indent + "Unbreakable term: {0}", match.Groups ["Terms"].Captures [0]);
+				//Log.Debug (indent + "Unbreakable term: {0}", match.Groups ["Terms"].Captures [0]);
 				string literal;
 				bool is_negated = false;
 				Tag tag = null;
@@ -312,7 +312,7 @@ namespace FSpot.Widgets {
 						subterm = subterm.Remove (0, 1);
 					}
 
-					//Log.DebugFormat (indent + "Breaking subterm apart: {0}", subterm);
+					//Log.Debug (indent + "Breaking subterm apart: {0}", subterm);
 
 					if (!ConstructQuery (us, depth + 1, subterm, negated))
 						return false;
@@ -330,7 +330,7 @@ namespace FSpot.Widgets {
 						subterm = subterm.Remove (0, 1);
 					}
 
-					//Log.DebugFormat (indent + "Breaking not subterm apart: {0}", subterm);
+					//Log.Debug (indent + "Breaking not subterm apart: {0}", subterm);
 
 					if (!ConstructQuery (us, depth + 1, subterm, true))
 						return false;
@@ -392,7 +392,7 @@ namespace FSpot.Widgets {
 
 			if (ParensValid () && ConstructQuery (null, 0, entry.Text)) {
 				if (RootTerm != null) {
-					//Log.DebugFormat("rootTerm = {0}", RootTerm);
+					//Log.Debug("rootTerm = {0}", RootTerm);
 					if (!(RootTerm is AndTerm)) {
 						// A little hacky, here to make sure the root term is a AndTerm which will
 						// ensure we handle the Hidden tag properly
@@ -401,7 +401,7 @@ namespace FSpot.Widgets {
 						root_term = root_parent;
 					}
 
-					//Log.DebugFormat("rootTerm = {0}", RootTerm);
+					//Log.Debug("rootTerm = {0}", RootTerm);
 					if (!(RootTerm is AndTerm)) {
 						// A little hacky, here to make sure the root term is a AndTerm which will
 						// ensure we handle the Hidden tag properly
@@ -409,10 +409,10 @@ namespace FSpot.Widgets {
 						RootTerm.Parent = root_parent;
 						root_term = root_parent;
 					}
-					//Log.DebugFormat ("condition = {0}", RootTerm.SqlCondition ());
-					query.ExtraCondition = RootTerm.SqlCondition ();
+					//Log.Debug ("condition = {0}", RootTerm.SqlCondition ());
+					query.TagTerm = new TagConditionWrapper (RootTerm.SqlCondition ());
 				} else {
-					query.ExtraCondition = null;
+					query.TagTerm = null;
 					//Log.Debug ("root term is null");
 				}
 			}
@@ -509,7 +509,7 @@ namespace FSpot.Widgets {
 			entry.DeleteText (entry.Position - transformed_key.Length, entry.Position);
 
 			string name = args.Model.GetValue (args.Iter, TextColumn) as string;
-			//Log.DebugFormat ("match selected..{0}", name);
+			//Log.Debug ("match selected..{0}", name);
 			int pos = entry.Position;
 
 			completing = true;
@@ -543,7 +543,7 @@ namespace FSpot.Widgets {
 					int start = 0;
 					for (int i = entry.Position - 1; i >= 0; i--) {
 						if (key [i] == ' ' || key [i] == ')' || key [i] == '(') {
-							//Log.DebugFormat ("have start break char at {0}", i);
+							//Log.Debug ("have start break char at {0}", i);
 							start = i + 1;
 							break;
 						}
@@ -557,7 +557,7 @@ namespace FSpot.Widgets {
 						}
 					}
 
-					//Log.DebugFormat ("start = {0} end = {1}", start, end);
+					//Log.Debug ("start = {0} end = {1}", start, end);
 
 					int len = end - start + 1;
 					if (len > 0 && start < last_key.Length)
@@ -565,7 +565,7 @@ namespace FSpot.Widgets {
 					else
 						transformed_key = String.Empty;
 				}
-				//Log.DebugFormat ("transformed key {0} into {1}", key, transformed_key);
+				//Log.Debug ("transformed key {0} into {1}", key, transformed_key);
 			}
 
 			if (transformed_key == String.Empty)
@@ -577,7 +577,7 @@ namespace FSpot.Widgets {
 			if (name == null || name.Length <= transformed_key.Length)
 				return false;
 
-			//Log.DebugFormat ("entered = {0} compared to {1}", transformed_key, name);
+			//Log.Debug ("entered = {0} compared to {1}", transformed_key, name);
 			return (String.Compare (transformed_key, name.Substring(0, transformed_key.Length), true) == 0);
 		}
 	}
