@@ -343,8 +343,8 @@ namespace FSpot.Widgets
 									 Width = Allocation.Width,
 									 Height = Allocation.Height,
 									 Wclass = Gdk.WindowClass.InputOutput,
-									 Visual = this.Visual,
-									 Colormap = this.Colormap,
+									 Visual = ParentWindow.Visual,
+									 Colormap = ParentWindow.Colormap,
 									 Mask = this.Events
 									      | EventMask.ExposureMask
 									      | EventMask.ButtonPressMask
@@ -441,14 +441,12 @@ namespace FSpot.Widgets
 
 				//draw synchronously if InterpType.Nearest or zoom 1:1
 				if (Interpolation == InterpType.Nearest || zoom == 1.0) {
-					PaintRectangle (p_area, Interpolation);
+					PaintRectangle (p_area, InterpType.Nearest);
 					continue;
 				}
 				
-				//delay all other interpolation types
-//				GLib.Idle.Add (...);
-
-				PaintRectangle (p_area, InterpType.Nearest);
+				//Do this on idle ???
+				PaintRectangle (p_area, Interpolation);
 			}
 			
 			if (can_select)
@@ -921,8 +919,11 @@ namespace FSpot.Widgets
 			if (evnt.Button != 1)
 				return false;
 
-			if (evnt.Type == EventType.TwoButtonPress) 
+			if (evnt.Type == EventType.TwoButtonPress) {
+				is_dragging_selection = false;
+				is_moving_selection = false;
 				return false;
+			}
 			
 			Point img = WindowCoordsToImage (new Point ((int)evnt.X, (int)evnt.Y));
 			switch (GetDragMode ((int)evnt.X, (int)evnt.Y)) {
